<?php
/*
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC. All rights reserved.                        |
 |                                                                    |
 | This work is published under the GNU AGPLv3 license with some      |
 | permitted exceptions and without any warranty. For full license    |
 | and copyright information, see https://civicrm.org/licensing       |
 +--------------------------------------------------------------------+
 */

namespace Civi\Api4\Action\ContributionRecur;

use Civi\Api4\ContributionRecur;
use Civi\Api4\Generic\AbstractAction;
use Civi\Api4\Generic\DAOGetAction;
use Civi\Api4\Generic\DAOUpdateAction;

/**
 * @inheritDoc
 */
class ImportStripesubscription extends DAOGetAction {

  /**
   * Link to existing membership automatically: Default: TRUE
   *
   * @var bool
   */
  protected bool $membershipAuto = TRUE;

  /**
   * Disable updates to Memberships when completing contribution: Default: FALSE
   *
   * @var bool
   */
  protected bool $membershipDisableUpdate = FALSE;

  /**
   * @param \Civi\Api4\Generic\Result $result
   *
   * @return void
   * @throws \CRM_Core_Exception
   * @throws \Civi\API\Exception\UnauthorizedException
   * @throws \Civi\Payment\Exception\PaymentProcessorException
   * @throws \Stripe\Exception\ApiErrorException
   */
  public function _run(\Civi\Api4\Generic\Result $result) {
    $importer = new \Civi\StripeImport\Subscription();

    if (!empty($this->where)) {
      $contributionRecurs = \Civi\Api4\ContributionRecur::get(FALSE)
        ->setWhere($this->where)
        ->execute();
    }
    else {
      throw new \CRM_Core_Exception('Must specify a where clause!');
    }

    foreach ($contributionRecurs as $contributionRecur) {
      $importer->resetOne();
      $importer->setContributionRecurID($contributionRecur['id']);
      if (empty($contributionRecur['processor_id']) || substr_compare($contributionRecur['processor_id'], 'sub_', 0, 4) !== 0) {
        \Civi::log()->error('Contribution Recur ID: ' . $contributionRecur['id'] . ' specified has invalid or no processor_id');
        continue;
      }
      $importer->setStripeSubscriptionID($contributionRecur['processor_id']);
      $importer->setPaymentProcessorID($contributionRecur['payment_processor_id']);
      $importer->setContactID($contributionRecur['contact_id']);
      $importer->setEmailReceipt($contributionRecur['is_email_receipt']);
      $importer->setFinancialTypeID($contributionRecur['financial_type_id']);
      $importer->setPaymentInstrumentID($contributionRecur['payment_instrument_id']);
      $importer->setMembershipAuto($this->membershipAuto);
      $importer->setMembershipDisableUpdates($this->membershipDisableUpdate);
      try {
        $results[] = $importer->importOne();
      }
      catch (\Exception $e) {
        \Civi::log()->error('Error importing stripe subscription for Recur: ' . $contributionRecur['id'] . ': ' . $e->getMessage());
      }
    }

    $result->exchangeArray($results ?? []);
  }

}
