<?php
/*
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC. All rights reserved.                        |
 |                                                                    |
 | This work is published under the GNU AGPLv3 license with some      |
 | permitted exceptions and without any warranty. For full license    |
 | and copyright information, see https://civicrm.org/licensing       |
 +--------------------------------------------------------------------+
 */

namespace Civi\StripeImport\Event;

use Civi\Core\Event\GenericHookEvent;

/**
 * If you specify "membership_auto" for Subscription Import this event will be triggered
 * to allow you to customise the "automatic" membership selection.
 */
class MembershipAutoEvent extends GenericHookEvent {

  /**
   * @var int
   */
  public int $contactID;

  /**
   * @var int
   */
  public int $contributionRecurID;

  /**
   * @var bool
   */
  public bool $isTest;

  /**
   * @var \Stripe\Subscription|null
   */
  public ?\Stripe\Subscription $stripeSubscription;

  /**
   * The membership ID to use
   *
   * @var int
   */
  public int $membershipID;

  /**
   * @param int $contactID
   * @param int $contributionRecurID
   * @param bool $isTest
   * @param \Stripe\Subscription|null $stripeSubscription
   */
  public function __construct(int $contactID, int $contributionRecurID, bool $isTest = FALSE, ?\Stripe\Subscription $stripeSubscription = NULL) {
    $this->contactID = $contactID;
    $this->contributionRecurID = $contributionRecurID;
    $this->isTest = $isTest;
    $this->stripeSubscription = $stripeSubscription;
  }

}
