<?php
/*
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC. All rights reserved.                        |
 |                                                                    |
 | This work is published under the GNU AGPLv3 license with some      |
 | permitted exceptions and without any warranty. For full license    |
 | and copyright information, see https://civicrm.org/licensing       |
 +--------------------------------------------------------------------+
 */

namespace Civi\StripeImport\Event;

/**
 * This event is fired whenever an import for a stripe object is started.
 */
class StartImportEvent extends \Civi\Core\Event\GenericHookEvent {

  /**
   * The CiviCRM payment processor ID
   *
   * @var int
   */
  public int $paymentProcessorID;

  /**
   * The Stripe Object ID. Eg. if $importType='subscription' then ObjectID = Stripe SubscriptionID.
   * @var string
   */
  public string $stripeObjectID;

  /**
   * One of: 'subscription', ... to be confirmed.
   * @var string
   */
  public string $importType;

  /**
   * The membership ID to use
   *
   * @var int
   */
  public int $membershipID;

  /**
   * @param int $paymentProcessorID
   * @param string $stripeObjectID
   * @param string $importType
   */
  public function __construct(int $paymentProcessorID, string $stripeObjectID, string $importType) {
    $this->paymentProcessorID = $paymentProcessorID;
    $this->stripeObjectID = $stripeObjectID;
    $this->importType = $importType;
  }

}
