<?php
namespace Civi\StripeImport;

use Civi\Core\Service\AutoService;
use Civi\Core\Service\IsActiveTrait;
use Civi\Api4\Membership;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class MembershipSubscriber
 * @package Civi\StripeImport
 * @service civi_stripeimport_membershipauto
 *
 * This class handles the membership choice
 */
class MembershipSubscriber extends AutoService implements EventSubscriberInterface {

  use IsActiveTrait;

  /**
   * @inheritDoc
   */
  public static function getSubscribedEvents(): array {
    return [
      'civi.stripeimport.membershipauto' => ['onMembershipAuto', 0],
    ];
  }

  /**
   * Apply the various CRM_Utils_Token helpers.
   *
   * @param \Civi\StripeImport\Event\MembershipAutoEvent $event
   */
  public function onMembershipAuto(\Civi\StripeImport\Event\MembershipAutoEvent $event): void {
    if (!$this->isActive()) {
      return;
    }

    // Get the already mapped membership
    //   OR the most recent (by ID) unmapped current membership.
    $membership = Membership::get(FALSE)
      ->addWhere('contact_id', '=', $event->contactID)
      ->addWhere('is_test', '=', $event->isTest)
      ->addWhere('status_id.is_current_member', '=', TRUE)
      ->addClause('OR', ['contribution_recur_id', '=', $event->contributionRecurID], ['contribution_recur_id', 'IS NULL'])
      ->addOrderBy('contribution_recur_id', 'DESC')
      ->addOrderBy('id', 'DESC')
      ->execute()
      ->first();

    if (!empty($membership)) {
      $event->membershipID = $membership['id'];
    }
  }

}
