<?php

namespace Civi\StripeImport;

use Civi\Api4\FinancialType;
use Civi\Api4\OptionValue;

class Settings {

  /**
   * Used by stripeimport_default_financial_type setting.
   *
   * Returns a list of active financial types
   */
  public static function getAllowedFinancialTypes(): array {
    return FinancialType::get(FALSE)
      ->addSelect('name')
      ->addWhere('is_active', '=', TRUE)
      ->addOrderBy('name', 'ASC')
      ->execute()
      ->indexBy('id')
      ->column('name');
  }

  /**
   * Used by stripeimport_default_financial_type setting.
   *
   * Returns a list of active financial types
   */
  public static function getAllowedPaymentInstruments(): array {
    return OptionValue::get(FALSE)
      ->addSelect('label')
      ->addWhere('option_group_id:name', '=', 'payment_instrument')
      ->addWhere('is_active', '=', TRUE)
      ->execute()
      ->indexBy('id')
      ->column('label');
  }

}