<?php
/*
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC. All rights reserved.                        |
 |                                                                    |
 | This work is published under the GNU AGPLv3 license with some      |
 | permitted exceptions and without any warranty. For full license    |
 | and copyright information, see https://civicrm.org/licensing       |
 +--------------------------------------------------------------------+
 */

use CRM_Stripe_ExtensionUtil as E;

/**
 * Stripe.Importcharges
 *
 * @param array $spec description of fields supported by this API call
 */
function _civicrm_api3_stripe_importcharge_spec(&$spec) {
  $spec['charge']['title'] = E::ts('Stripe Charge ID');
  $spec['charge']['description'] = E::ts('The Charge ID to import');
  $spec['charge']['type'] = CRM_Utils_Type::T_STRING;
  $spec['charge']['api.required'] = TRUE;
  $spec['contact_id']['title'] = E::ts('Contact ID');
  $spec['contact_id']['description'] = E::ts('If not specified this will be determined from the "customer" on the charge - a StripeCustomer record must exist in CiviCRM');
  $spec['contact_id']['type'] = CRM_Utils_Type::T_INT;
  $spec['contribution_source'] = [
    'title' => 'Contribution Source (optional description for contribution)',
    'type' => CRM_Utils_Type::T_STRING,
  ];
  $spec['contribution_id']['title'] = E::ts('Optionally, provide contribution ID of existing contribution you want to link to.');
  $spec['contribution_id']['type'] = CRM_Utils_Type::T_INT;

  _civicrm_api3_stripe_importcharge_shared_spec($spec);
}

/**
 * API to import a stripe charge, create a customer and contribution.
 * You run it once for each charge and it creates/updates a contribution in CiviCRM
 *
 * @param array $params
 *
 * @return array
 * @throws \CRM_Core_Exception
 * @throws \Civi\API\Exception\UnauthorizedException
 * @throws \Civi\Payment\Exception\PaymentProcessorException
 * @throws \Stripe\Exception\ApiErrorException
 */
function civicrm_api3_stripe_importcharge($params) {
  $chargeImport = new \Civi\StripeImport\Charge();
  $chargeImport->setPaymentProcessorID($params['ppid']);
  $chargeImport->setStripeChargeID($params['charge']);
  if (!empty($params['contact_id'])) {
    $chargeImport->setContactID($params['contact_id']);
  }
  if (!empty($params['contribution_source'])) {
    $chargeImport->setDescription($params['contribution_source']);
  }
  if (!empty($params['contribution_id'])) {
    $chargeImport->setContributionID($params['contribution_id']);
  }
  $chargeImport->setFinancialTypeID($params['financial_type_id']);
  $chargeImport->setPaymentInstrumentID($params['payment_instrument_id']);
  $result = $chargeImport->importOne();
  return civicrm_api3_create_success($result, $params, 'Stripe', 'Importcharge');
}
