<?php
/*
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC. All rights reserved.                        |
 |                                                                    |
 | This work is published under the GNU AGPLv3 license with some      |
 | permitted exceptions and without any warranty. For full license    |
 | and copyright information, see https://civicrm.org/licensing       |
 +--------------------------------------------------------------------+
 */

use CRM_Stripe_ExtensionUtil as E;

/**
 * Stripe.Importcharges
 *
 * @param array $spec description of fields supported by this API call
 */
function _civicrm_api3_stripe_importcharges_spec(&$spec) {
  $spec['limit']['title'] = E::ts('Limit number of charges to be imported');
  $spec['limit']['type'] = CRM_Utils_Type::T_INT;
  $spec['limit']['api.required'] = FALSE;
  $spec['starting_after']['title'] = E::ts('Start importing charges after this one');
  $spec['starting_after']['type'] = CRM_Utils_Type::T_STRING;
  $spec['starting_after']['api.required'] = FALSE;
  $spec['created_before']['type'] = CRM_Utils_Type::T_TIMESTAMP;
  $spec['created_before']['title'] = E::ts('Import charges before this date');
  $spec['created_before']['description'] = E::ts('Use an absolute date eg. 20240102000000 or relative eg. -1 week');
  $spec['created_after']['type'] = CRM_Utils_Type::T_TIMESTAMP;
  $spec['created_after']['title'] = E::ts('Import charges after this date');
  $spec['created_after']['description'] = E::ts('Use an absolute date eg. 20240102000000 or relative eg. -1 week');

  _civicrm_api3_stripe_importcharge_shared_spec($spec);
}

/**
 * Stripe.Importcharges API
 *
 * @param array $params
 *
 * @return array
 * @throws \CRM_Core_Exception
 */
function civicrm_api3_stripe_importcharges($params) {
  if (isset($params['created_after']) && isset($params['created_before'])) {
    throw new CRM_Core_Exception('Invalid parameter: can only specify one of created_before/created_after');
  }
  if (empty($params['created_after']) && empty($params['created_before']) && empty($params['starting_after'])) {
    throw new CRM_Core_Exception('Invalid parameters: You must specify one of created_before, created_after or starting_after');
  }

  $importer = new \Civi\StripeImport\Charge();
  $importer->setPaymentProcessorID($params['ppid']);
  $importer->setFinancialTypeID($params['financial_type_id']);
  $importer->setPaymentInstrumentID($params['payment_instrument_id']);
  $stripeAPIFilters = [
    'limit' => $params['limit'] ?? 100,
    'starting_after' => $params['starting_after'] ?? NULL,
    'created_before' => $params['created_before'] ?? NULL,
    'created_after' => $params['created_after'] ?? NULL,
  ];
  $return = $importer->importMultiple($stripeAPIFilters);

  return civicrm_api3_create_success($return, $params, 'Stripe', 'Importcharges');
}
