<?php
/*
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC. All rights reserved.                        |
 |                                                                    |
 | This work is published under the GNU AGPLv3 license with some      |
 | permitted exceptions and without any warranty. For full license    |
 | and copyright information, see https://civicrm.org/licensing       |
 +--------------------------------------------------------------------+
 */

use CRM_Stripe_ExtensionUtil as E;

/**
 * @param array $spec
 */
function _civicrm_api3_stripe_importsubscription_spec(&$spec) {
  $spec['subscription']['title'] = E::ts('Stripe Subscription ID');
  $spec['subscription']['type'] = CRM_Utils_Type::T_STRING;
  $spec['subscription']['api.required'] = TRUE;
  $spec['contact_id']['title'] = E::ts('Contact ID');
  $spec['contact_id']['description'] = E::ts('If not specified this will be determined from the "customer" on the subscription - a StripeCustomer record must exist in CiviCRM');
  $spec['contact_id']['type'] = CRM_Utils_Type::T_INT;
  $spec['recur_id']['title'] = E::ts('Contribution Recur ID');
  $spec['recur_id']['type'] = CRM_Utils_Type::T_INT;
  $spec['contribution_id']['title'] = E::ts('Contribution ID');
  $spec['contribution_id']['type'] = CRM_Utils_Type::T_INT;
  $spec['membership_id']['title'] = E::ts('Membership ID');
  $spec['membership_id']['type'] = CRM_Utils_Type::T_INT;
  $spec['contribution_source'] = [
    'title' => 'Contribution Source (optional description for contribution)',
    'type' => CRM_Utils_Type::T_STRING,
  ];

  _civicrm_api3_stripe_importsubscription_shared_spec($spec);
}

/**
 * API to import a stripe subscription, create a customer, recur, contribution and optionally link to membership
 * You run it once for each subscription and it creates/updates a recurring contribution in civicrm (and optionally links it to a membership).
 *
 * @param array $params
 *
 * @return array
 * @throws \CRM_Core_Exception
 * @throws \Civi\API\Exception\UnauthorizedException
 * @throws \Civi\Payment\Exception\PaymentProcessorException
 * @throws \Stripe\Exception\ApiErrorException
 */
function civicrm_api3_stripe_importsubscription($params) {
  $importer = new \Civi\StripeImport\Subscription();
  $importer->setPaymentProcessorID($params['ppid']);
  $importer->setStripeSubscriptionID($params['subscription']);
  if (!empty($params['contact_id'])) {
    $importer->setContactID($params['contact_id']);
  }
  if (!empty($params['recur_id'])) {
    $importer->setContributionRecurID($params['recur_id']);
  }
  if (!empty($params['contribution_source'])) {
    $importer->setDescription($params['contribution_source']);
  }
  $importer->setEmailReceipt($params['is_email_receipt']);
  $importer->setFinancialTypeID($params['financial_type_id']);
  $importer->setPaymentInstrumentID($params['payment_instrument_id']);
  if (!empty($params['membership_id'])) {
    $importer->setMembershipID($params['membership_id']);
  }
  $importer->setMembershipAuto($params['membership_auto']);
  $importer->setMembershipDisableUpdates($params['membership_disableupdate']);
  if (!empty($params['subscription_exclude_statuses'])) {
    $importer->setSubscriptionExcludeStatuses($params['subscription_exclude_statuses']);
  }
  $return = $importer->importOne();

  return civicrm_api3_create_success($return, $params, 'Stripe', 'Importsubscription');
}
