<?php
/*
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC. All rights reserved.                        |
 |                                                                    |
 | This work is published under the GNU AGPLv3 license with some      |
 | permitted exceptions and without any warranty. For full license    |
 | and copyright information, see https://civicrm.org/licensing       |
 +--------------------------------------------------------------------+
 */

use CRM_Stripe_ExtensionUtil as E;

return [
  'stripeimport_notmatched_customer_create' => [
    'name' => 'stripeimport_notmatched_customer_create',
    'type' => 'Boolean',
    'html_type' => 'checkbox',
    'default' => 0,
    'is_domain' => 1,
    'is_contact' => 0,
    'title' => E::ts('Stripe Import: Automatically create missing contact'),
    'description' => E::ts('If a webhook is received, the event type is charge.succeeded/charge.failed, the contribution is not matched to an existing contribution in
    CiviCRM and the customer is not matched to a contact in CiviCRM then create a new contact using the details held at Stripe.'),
    'html_attributes' => [],
    'settings_pages' => [
      'stripe' => [
        'weight' => 200,
      ]
    ],
  ],
  'stripeimport_notmatched_charge_find' => [
    'name' => 'stripeimport_notmatched_charge_find',
    'type' => 'Boolean',
    'html_type' => 'checkbox',
    'default' => 0,
    'is_domain' => 1,
    'is_contact' => 0,
    'title' => E::ts('Stripe Import: Automatically match missing contribution'),
    'description' => E::ts('If a webhook is received, the event type is charge.succeeded/charge.failed and the contribution is not matched to an existing contribution in
    CiviCRM then try to match with an existing contribution using the receive_date and total amount of the charge.'),
    'html_attributes' => [],
    'settings_pages' => [
      'stripe' => [
        'weight' => 210,
      ]
    ],
  ],
  'stripeimport_notmatched_charge_create' => [
    'name' => 'stripeimport_notmatched_charge_create',
    'type' => 'Boolean',
    'html_type' => 'checkbox',
    'default' => 0,
    'is_domain' => 1,
    'is_contact' => 0,
    'title' => E::ts('Stripe Import: Automatically create missing contribution'),
    'description' => E::ts('If a webhook is received, the event type is charge.succeeded/charge.failed and the contribution is not matched to an existing contribution in
    CiviCRM then create a new contribution using the parameters from the charge.'),
    'html_attributes' => [],
    'settings_pages' => [
      'stripe' => [
        'weight' => 220,
      ]
    ],
  ],
  'stripeimport_chargeimport_subscriptioncharges' => [
    'name' => 'stripeimport_chargeimport_subscriptioncharges',
    'type' => 'Boolean',
    'html_type' => 'checkbox',
    'default' => 0,
    'is_domain' => 1,
    'is_contact' => 0,
    'title' => E::ts('Stripe Import: Import subscription charges using Charge importer'),
    'description' => E::ts('By default Stripe Charges linked to subscriptions are ignored by the Charge importer as they are handled by the subscription importer.
    If you enable this setting the Charge importer will also import charges that are linked to subscriptions (but without creating the recurring contribution).'),
    'html_attributes' => [],
    'settings_pages' => [
      'stripe' => [
        'weight' => 225,
      ]
    ],
  ],
  'stripeimport_chargeimport_sendreceipt' => [
    'name' => 'stripeimport_chargeimport_sendreceipt',
    'type' => 'Boolean',
    'html_type' => 'checkbox',
    'default' => 0,
    'is_domain' => 1,
    'is_contact' => 0,
    'title' => E::ts('Stripe Import: Send Receipt when importing a successful charge'),
    'description' => E::ts('CiviCRM sends a receipt automatically when a contribution is completed (successful charge is imported). This setting tells CiviCRM whether or not to send the receipt.'),
    'html_attributes' => [],
    'settings_pages' => [
      'stripe' => [
        'weight' => 226,
      ]
    ],
  ],
  'stripeimport_default_financial_type' => [
    'name' => 'stripeimport_default_financial_type',
    'type' => 'Integer',
    'html_type' => 'select',
    'default' => 1,
    'is_domain' => 1,
    'is_contact' => 0,
    'title' => E::ts('Stripe Import: Default financial type'),
    'description' => E::ts('If financial type was not specified or cannot be detected automatically use this one.'),
    'html_attributes' => [
      'placeholder' => E::ts('- select -'),
      'class' => 'crm-select2',
    ],
    'pseudoconstant' => ['callback' => '\Civi\StripeImport\Settings::getAllowedFinancialTypes'],
    'settings_pages' => [
      'stripe' => [
        'weight' => 230,
      ]
    ],
  ],
  'stripeimport_default_payment_instrument' => [
    'name' => 'stripeimport_default_payment_instrument',
    'type' => 'Integer',
    'html_type' => 'select',
    'default' => 1,
    'is_domain' => 1,
    'is_contact' => 0,
    'title' => E::ts('Stripe Import: Default Payment Instrument'),
    'description' => E::ts('If payment instrument was not specified or cannot be detected automatically use this one.'),
    'html_attributes' => [
      'placeholder' => E::ts('- select -'),
      'class' => 'crm-select2',
    ],
    'pseudoconstant' => ['callback' => '\Civi\StripeImport\Settings::getAllowedPaymentInstruments'],
    'settings_pages' => [
      'stripe' => [
        'weight' => 230,
      ]
    ],
  ],
];
