<?php

require_once 'stripeimport.civix.php';
// phpcs:disable
use CRM_Stripeimport_ExtensionUtil as E;
// phpcs:enable

/**
 * Implements hook_civicrm_config().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_config/
 */
function stripeimport_civicrm_config(&$config): void {
  _stripeimport_civix_civicrm_config($config);
}

/**
 * Implements hook_civicrm_install().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_install
 */
function stripeimport_civicrm_install(): void {
  _stripeimport_civix_civicrm_install();
}

/**
 * Implements hook_civicrm_enable().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_enable
 */
function stripeimport_civicrm_enable(): void {
  _stripeimport_civix_civicrm_enable();
}

function _civicrm_api3_stripe_importcustomer_shared_spec(&$spec) {
  $spec['ppid']['title'] = E::ts('Use the given Payment Processor ID');
  $spec['ppid']['type'] = CRM_Utils_Type::T_INT;
  $spec['ppid']['api.required'] = TRUE;

  $spec['create_missing_contact']['title'] = E::ts('Create missing contact');
  $spec['create_missing_contact']['description'] = E::ts('(default: true) If contact is not found in CiviCRM create it automatically');
  $spec['create_missing_contact']['type'] = CRM_Utils_Type::T_BOOLEAN;
  $spec['create_missing_contact']['api.required'] = FALSE;
  $spec['create_missing_contact']['api.default'] = TRUE;
}

function _civicrm_api3_stripe_importsubscription_shared_spec(&$spec) {
  $spec['ppid']['title'] = E::ts('Payment Processor ID');
  $spec['ppid']['type'] = CRM_Utils_Type::T_INT;
  $spec['ppid']['api.required'] = TRUE;

  $spec['financial_type_id'] = [
    'title' => E::ts('Financial Type ID'),
    'type' => CRM_Utils_Type::T_STRING,
    'pseudoconstant' => [
      'table' => 'civicrm_financial_type',
      'keyColumn' => 'id',
      'labelColumn' => 'name',
    ],
    'api.default' => 1,
  ];

  $spec['payment_instrument_id'] = [
    'title' => E::ts('Payment Instrument ID'),
    'type' => CRM_Utils_Type::T_STRING,
    'api.default' => 1,
  ];

  $spec['is_email_receipt']['title'] = E::ts('Send Email Receipt (default: no)');
  $spec['is_email_receipt']['type'] = CRM_Utils_Type::T_BOOLEAN;
  $spec['is_email_receipt']['api.default'] = FALSE;

  $spec['membership_auto']['title'] = E::ts('Link to existing membership automatically');
  $spec['membership_auto']['description'] = E::ts('Default: Yes');
  $spec['membership_auto']['type'] = CRM_Utils_Type::T_BOOLEAN;
  $spec['membership_auto']['api.default'] = TRUE;

  $spec['membership_disableupdate']['title'] = E::ts('Disable updates to Memberships when completing contribution');
  $spec['membership_disableupdate']['description'] = E::ts('Default: No');
  $spec['membership_disableupdate']['type'] = CRM_Utils_Type::T_BOOLEAN;
  $spec['membership_disableupdate']['api.default'] = FALSE;

  $spec['subscription_exclude_statuses']['title'] = E::ts('Exclude recurring contribution statuses');
  $spec['subscription_exclude_statuses']['description'] = E::ts('See https://docs.stripe.com/api/subscriptions/object#subscription_object-status - specify comma separated list of subscription statuses to exclude');
  $spec['subscription_exclude_statuses']['type'] = CRM_Utils_Type::T_STRING;
}

function _civicrm_api3_stripe_importcharge_shared_spec(&$spec) {
  $spec['ppid']['title'] = E::ts('Payment Processor ID');
  $spec['ppid']['type'] = CRM_Utils_Type::T_INT;
  $spec['ppid']['api.required'] = TRUE;

  $spec['financial_type_id'] = [
    'title' => E::ts('Financial Type ID'),
    'type' => CRM_Utils_Type::T_STRING,
    'pseudoconstant' => [
      'table' => 'civicrm_financial_type',
      'keyColumn' => 'id',
      'labelColumn' => 'name',
    ],
    'api.default' => 1,
  ];

  $spec['payment_instrument_id'] = [
    'title' => E::ts('Payment Instrument ID'),
    'type' => CRM_Utils_Type::T_STRING,
    'api.default' => 1,
  ];
}

/**
 * Implements search tasks hook to add the `validate` and `import` actions.
 *
 * @param array $tasks
 * @param bool $checkPermissions
 * @param int|null $userId
 *
 * @noinspection PhpUnused
 */
function stripeimport_civicrm_searchKitTasks(array &$tasks, bool $checkPermissions, ?int $userId) {
  $tasks['ContributionRecur']['import_stripe_subscription'] = [
    'title' => E::ts('Import Stripe Subscription'),
    'icon' => 'fa-gear',
    'apiBatch' => [
      'action' => 'importStripesubscription',
      'params' => NULL,
      'runMsg' => E::ts('Importing %1 subscription/s...'),
      'successMsg' => E::ts('Successfully imported %1 subscription/s.'),
      'errorMsg' => E::ts('An error occurred while attempting to import %1 subscription/s.'),
    ],
  ];
}

/**
 * @param string $type The type of webhook - eg. 'stripe'
 * @param object $object The object (eg. CRM_Core_Payment_StripeIPN)
 * @param string $code "Code" to identify what was not matched (eg. customer_not_found)
 * @param array $result Results returned by hook processing. Depends on the type/code. Eg. for stripe.contribution_not_found return $result['contribution'] = "contribution array from API"
 *
 * @return void
 * @throws \CRM_Core_Exception
 * @throws \Civi\API\Exception\UnauthorizedException
 * @throws \Civi\Payment\Exception\PaymentProcessorException
 * @throws \Stripe\Exception\ApiErrorException
 */
function stripeimport_civicrm_webhook_eventNotMatched(string $type, Object $object, string $code, array &$result) {
  if ($type !== 'stripe') {
    return;
  }
  if (!($object instanceof \Civi\Stripe\Webhook\Events)) {
    return;
  }

  /** @var \Civi\Stripe\Webhook\Events $object */

  switch ($code) {
    case 'contribution_not_found':
      \Civi::log('stripeimport')->info('StripeImport: START webhook_eventNotMatched handler. Params: event: ' . $object->getEventType() . ', code: ' . $code);

      // We are only going to try to find a contribution for the "invoice.payment_succeeded" webhook.
      if (!in_array($object->getEventType(), ['charge.succeeded', 'charge.failed'])) {
        \Civi::log('stripeimport')->info('StripeImport: webhook_eventNotMatched: Handling event: ' . $object->getEventType() . ' is not currently supported');
        return;
      }

      $chargeID = \CRM_Stripe_Api::getObjectParam('charge_id', $object->getData()->object);
      if (empty($chargeID)) {
        \Civi::log('stripeimport')->info('StripeImport: webhook_eventNotMatched: Charge ID not found: ' . $object->getEventType());
        return;
      }

      $chargeImport = new \Civi\StripeImport\Charge();
      $chargeImport->setPaymentProcessorID($object->getPaymentProcessor()->getID());
      $chargeImport->setStripeChargeID($chargeID);
      $chargeImport->setFinancialTypeID(\Civi::settings()->get('stripeimport_default_financial_type'));
      $chargeImport->setPaymentInstrumentID(\Civi::settings()->get('stripeimport_default_payment_instrument'));
      $chargeImport->handleWebhookEventNotMatched($object->getData()->object, $result);
      break;
  }
}
